Index: /trunk/XTIDE_Universal_BIOS/Src/Handlers/Int19h.asm
===================================================================
--- /trunk/XTIDE_Universal_BIOS/Src/Handlers/Int19h.asm	(revision 603)
+++ /trunk/XTIDE_Universal_BIOS/Src/Handlers/Int19h.asm	(revision 604)
@@ -106,7 +106,7 @@
 	cli
 	mov		ax, [es:BOOTVARS.hotkeyVars+HOTKEYVARS.fpPrevTimerHandler]
-	mov		[es:BIOS_USER_TIMER_TICK_INTERRUPT_1Ch*4], ax
+	mov		[es:BIOS_SYSTEM_TIMER_TICK_INTERRUPT_08h*4], ax
 	mov		ax, [es:BOOTVARS.hotkeyVars+HOTKEYVARS.fpPrevTimerHandler+2]
-	mov		[es:BIOS_USER_TIMER_TICK_INTERRUPT_1Ch*4+2], ax
+	mov		[es:BIOS_SYSTEM_TIMER_TICK_INTERRUPT_08h*4+2], ax
 	sti
 %endif
Index: /trunk/XTIDE_Universal_BIOS/Src/Menus/HotkeyBar.asm
===================================================================
--- /trunk/XTIDE_Universal_BIOS/Src/Menus/HotkeyBar.asm	(revision 603)
+++ /trunk/XTIDE_Universal_BIOS/Src/Menus/HotkeyBar.asm	(revision 604)
@@ -23,5 +23,5 @@
 
 ;--------------------------------------------------------------------
 ; Handler for INT 1Ch User Timer Tick.
 ; Reads key presses and draws hotkey bar.
 ;
@@ -40,8 +40,4 @@
 	push	ax
 %endif
-
-	;!!! Keep interrupts disabled so there won't be another
-	; timer tick call before we are ready
-
 	LOAD_BDA_SEGMENT_TO es, ax
 
@@ -123,5 +119,5 @@
 
 	; Move cursor to top left corner (0, 0)
-	xor		ax, ax
+	mov		ax, es
 	call	HotkeyBar_SetCursorCoordinatesFromAX
 	; Fall to .PrintFloppyDriveHotkeys
@@ -265,10 +261,10 @@
 ; FormatDriveHotkeyString
 ;	Parameters:
-;		CH:			Zero if letter in CL is selected for boot
-;		CL:			Drive letter hotkey from BOOTVARS
-;		AL:			First character for drive key string
-;		AH:			Second character for drive key string (ANGLE_QUOTE_RIGHT)
-;		SI:			Offset to hotkey description string
-;		ES:			BDA segment (zero)
+;		CH:		Zero if letter in CL is selected for boot
+;		CL:		Drive letter hotkey from BOOTVARS
+;		AL:		First character for drive key string
+;		AH:		Second character for drive key string (ANGLE_QUOTE_RIGHT)
+;		SI:		Offset to hotkey description string
+;		ES:		BDA segment (zero)
 ;	Returns:
 ;		Nothing
@@ -292,9 +288,9 @@
 ; FormatFunctionHotkeyString
 ;	Parameters:
-;		AL:			Scancode of function key, to know which if any to show as selected
-;					Later replaced with an 'F' for the call to the output routine
-;		AH:			Second character for drive key string
-;		SI:			Offset to hotkey description string
-;		ES:			BDA segment (zero)
+;		AL:		Scancode of function key, to know which if any to show as selected
+;				Later replaced with an 'F' for the call to the output routine
+;		AH:		Second character for drive key string
+;		SI:		Offset to hotkey description string
+;		ES:		BDA segment (zero)
 ;	Returns:
 ;		Nothing
@@ -350,9 +346,9 @@
 ; PushHotkeyParamsAndFormat
 ;	Parameters:
-;		AL:			First character
-;		AH:			Second character
-;		DX:			Description Attribute
-;		CX:			Description string parameter
-;		CS:DI:		Description string
+;		AL:		First character
+;		AH:		Second character
+;		DX:		Description Attribute
+;		CX:		Description string parameter
+;		CS:DI:	Description string
 ;	Returns:
 ;		Nothing
@@ -413,10 +409,10 @@
 	pop		ds
 
-	; Store system 1Ch Timer Tick handler and install our hotkeybar handler
-	mov		ax, [BIOS_USER_TIMER_TICK_INTERRUPT_1Ch*4]
+	; Store System Timer Tick handler and install our hotkeybar handler
+	mov		ax, [BIOS_SYSTEM_TIMER_TICK_INTERRUPT_08h*4]
 	mov		[BOOTVARS.hotkeyVars+HOTKEYVARS.fpPrevTimerHandler], ax
-	mov		ax, [BIOS_USER_TIMER_TICK_INTERRUPT_1Ch*4+2]
+	mov		ax, [BIOS_SYSTEM_TIMER_TICK_INTERRUPT_08h*4+2]
 	mov		[BOOTVARS.hotkeyVars+HOTKEYVARS.fpPrevTimerHandler+2], ax
-	mov		al, BIOS_USER_TIMER_TICK_INTERRUPT_1Ch
+	mov		al, BIOS_SYSTEM_TIMER_TICK_INTERRUPT_08h
 	mov		si, HotkeyBar_TimerTickHandler
 	call	Interrupts_InstallHandlerToVectorInALFromCSSI
@@ -424,5 +420,5 @@
 	; Store time when hotkeybar is displayed
 	; (it will be displayed after initialization is complete)
-	call	TimerTicks_ReadFromBdaToAX
+	mov		ax, [BDA.dwTimerTicks]
 	mov		[BOOTVARS.hotkeyVars+HOTKEYVARS.wTimeWhenDisplayed], ax
 
@@ -23,5 +23,5 @@
 
 ;--------------------------------------------------------------------
-; Handler for INT 1Ch User Timer Tick.
+; Handler for INT 08h System Timer Tick.
 ; Reads key presses and draws hotkey bar.
 ;
